@@ -40,7 +40,8 @@ class ChatBot:
         self.event = Events(self.__WebSocketClient)
 
         if log_error_frames:
-            self.event.on_any(frame_type=FrameType.EROR)(lambda resp: self.__WebSocketClient.logger.error(resp))
+            self.event.on_any(func=lambda resp: self.__WebSocketClient.logger.error(resp), frame_type=FrameType.EROR,
+                              run_parallel=True)
 
     def get_own_name(self) -> str:
         return self.__WebSocketClient.own_name
@@ -79,7 +80,7 @@ class ChatBot:
                 self.__WebSocketClient.ws_send_message(response_prepped, resp.channel_url)
                 return True
 
-        self.event.on_any(frame_type=FrameType.MESG)(hook)
+        self.event.on_message(func=hook)
 
     def set_welcome_message(self, message: str, limited_to_channels: List[str] = None) -> None:
         if limited_to_channels is None:
@@ -221,9 +222,10 @@ class ChatBot:
         self.__WebSocketClient.add_channelid_sub_pair(channel)
         return channel
 
-    def accept_chat_invite(self, channel_url: str) -> None:
-        self.__tools.accept_chat_invite(channel_url, session_key=self.__WebSocketClient.session_key)
+    def accept_chat_invite(self, channel_url: str) -> Channel:
+        group = self.__tools.accept_chat_invite(channel_url, session_key=self.__WebSocketClient.session_key)
         self.__WebSocketClient.update_channelid_sub_pair()
+        return group
 
     def rename_channel(self, name: str, channel_url: str) -> Channel:
         channel = self.__tools.rename_channel(**_get_locals_without_self(locals()),
