@@ -2,17 +2,10 @@ import websocket
 from ._utils.rate_limiter import RateLimiter
 import time
 from ._utils.frame_model import get_frame_data, FrameType
-import logging
-from threading import Thread
-from ._utils import ws_utils
+from _thread import start_new_thread
+from ._utils.ws_utils import get_ws_url, print_chat_, configure_loggers, pair_channel_and_names
 from ._utils.consts import MESG_regular, MESG_snoo, MESG_gif, TPST, TPEN, USER_AGENT
 
-logging.basicConfig(level=logging.INFO, datefmt='%H:%M', format='%(asctime)s, %(levelname)s: %(message)s')
-
-
-def _print_chat_(resp, channelid_sub_pairs):
-    print(f"{resp.user.name}@{channelid_sub_pairs.get(resp.channel_url)}: {resp.message}")
-
 
 class WebSockClient:
     def __init__(self, access_token, user_id, get_current_channels, enable_trace=False, print_chat=True,
@@ -22,12 +15,11 @@ class WebSockClient:
         self.channelid_sub_pairs = {}
         self.RateLimiter = RateLimiter
 
-        self.logger = logging.getLogger(__name__)
+        self.logger = configure_loggers()
         self.logger.disabled = not other_logging
         websocket.enableTrace(enable_trace)
 
-        ws_url = ws_utils.get_ws_url(self._user_id, access_token)
-        self.ws = self._get_ws_app(ws_url)
+        self.ws = self._get_ws_app(get_ws_url(self._user_id, access_token))
 
         self.req_id = int(time.time() * 1000)
         self.own_name = None
@@ -41,6 +33,7 @@ class WebSockClient:
         self.current_channels = None
 
         self.after_message_hooks = []
+        self.parralel_hooks = []
 
     def _get_ws_app(self, ws_url):
         ws = websocket.WebSocketApp(ws_url,
@@ -53,7 +46,7 @@ class WebSockClient:
         return ws
 
     def update_ws_app_urls_access_token(self, access_token):
-        self.ws.url = ws_utils.get_ws_url(self._user_id, access_token)
+        self.ws.url = get_ws_url(self._user_id, access_token)
 
     def on_open(self, _):
         self.logger.info("### successfully connected to the websocket ###")
@@ -61,14 +54,17 @@ class WebSockClient:
     def on_message(self, _, message):
         resp = get_frame_data(message)
         if self.print_chat and resp.type_f == FrameType.MESG:
-            _print_chat_(resp, self.channelid_sub_pairs)
+            print_chat_(resp, self.channelid_sub_pairs)
         if self.log_websocket_frames:
             self.logger.info(message)
         if resp.type_f == FrameType.LOGI:
             self.logger.info(message)
             self._logi(resp)
 
-        Thread(target=self._response_loop, args=(resp,), daemon=True).start()
+        for func in self.parralel_hooks:
+            start_new_thread(func, (resp,))
+
+        start_new_thread(self._response_loop, (resp,))
 
     def _logi(self, resp):
         try:
@@ -82,7 +78,7 @@ class WebSockClient:
             self.update_channelid_sub_pair()
             self.own_name = resp.nickname
         else:
-            self.logger.error(f"err: {resp.message}")
+            self.logger.error(resp.message)
             self.is_logi_err = True
 
     def update_channelid_sub_pair(self):
@@ -91,14 +87,15 @@ class WebSockClient:
                                                           member_state_filter='joined_only', super_mode='all',
                                                           public_mode='all', unread_filter='all',
                                                           hidden_mode='all', show_frozen=True,
+                                                          # custom_types='direct,group',
                                                           session_key=self.session_key)
-        self.channelid_sub_pairs = ws_utils.pair_channel_and_names(channels=self.current_channels,
-                                                                   own_user_id=self._user_id)
+        self.channelid_sub_pairs = pair_channel_and_names(channels=self.current_channels,
+                                                          own_user_id=self._user_id)
 
     def add_channelid_sub_pair(self, channel):
         self.current_channels.append(channel)
-        self.channelid_sub_pairs = ws_utils.pair_channel_and_names(channels=self.current_channels,
-                                                                   own_user_id=self._user_id)
+        self.channelid_sub_pairs = pair_channel_and_names(channels=self.current_channels,
+                                                          own_user_id=self._user_id)
 
     def _response_loop(self, resp):
         for func in self.after_message_hooks:
@@ -119,8 +116,8 @@ class WebSockClient:
         self.ws.send(payload)
         self.req_id += 1
 
-    def ws_send_gif(self, gif_url, channel_url):
-        payload = MESG_gif.format(gif_url=gif_url, channel_url=channel_url)
+    def ws_send_gif(self, gif_url, channel_url, height, width):
+        payload = MESG_gif.format(gif_url=gif_url, channel_url=channel_url, height=height, width=width)
         self.ws.send(payload)
 
     def ws_send_typing_indicator(self, channel_url):
